"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useHttpEvent = void 0;
var react_1 = require("react");
var react_fast_compare_1 = __importDefault(require("react-fast-compare"));
var event_bus_context_1 = require("./event-bus-context");
var use_compare_layout_effect_1 = require("../shared/use-compare-layout-effect");
var useHttpEvent = function (eventType, handler) {
    // The event bus.
    var eventBus = (0, event_bus_context_1.useEventBus)();
    // A ref to unsubscribe from the event. It helps to avoid
    // registering the same event handler multiple times.
    var unsubscribeRef = (0, react_1.useRef)();
    /**
     * Detach the handler for the event.
     */
    var unsubscribe = (0, react_1.useCallback)(function () {
        if (unsubscribeRef.current) {
            unsubscribeRef.current();
            unsubscribeRef.current = undefined;
        }
    }, []);
    /**
     * Setup the event handler.
     */
    (0, use_compare_layout_effect_1.useCompareLayoutEffect)(function () {
        // Subscribe to the event and keep track of the subscription.
        unsubscribeRef.current = eventBus.subscribe(eventType, handler);
        // Clean up: unsubscribe the previous event handler.
        return function () {
            unsubscribe();
        };
    }, [eventBus, eventType, handler, unsubscribe], react_fast_compare_1.default);
};
exports.useHttpEvent = useHttpEvent;
