import { useRef, useCallback } from 'react';
import fastCompare from 'react-fast-compare';
import { useEventBus } from './event-bus-context';
import { useCompareLayoutEffect } from '../shared/use-compare-layout-effect';
export var useHttpEvent = function (eventType, handler) {
    // The event bus.
    var eventBus = useEventBus();
    // A ref to unsubscribe from the event. It helps to avoid
    // registering the same event handler multiple times.
    var unsubscribeRef = useRef();
    /**
     * Detach the handler for the event.
     */
    var unsubscribe = useCallback(function () {
        if (unsubscribeRef.current) {
            unsubscribeRef.current();
            unsubscribeRef.current = undefined;
        }
    }, []);
    /**
     * Setup the event handler.
     */
    useCompareLayoutEffect(function () {
        // Subscribe to the event and keep track of the subscription.
        unsubscribeRef.current = eventBus.subscribe(eventType, handler);
        // Clean up: unsubscribe the previous event handler.
        return function () {
            unsubscribe();
        };
    }, [eventBus, eventType, handler, unsubscribe], fastCompare);
};
